#!/bin/csh

# 1) set yMODE to Complex instead of Echo-AntiEcho before the two interleaved
#    data sets are separated, and then use the bruk_ranceY.M macro to reshuffle
#    the echo and antiecho data to convert the phase modulated data to amplitude
#    modulated data.

# 2) set yN to the total number of FIDs recorded for both experiments. Round it down
#    so that it can be divided by 8 for the interleaved data.

# 3) zN should be set to 1 and zMODE set to Real instead of complex

# 4) It is important to set ndim to 2 to treat the 3D as 2D before NUS expansion

# 5) After the conversion, each separate data set is then reshuffled and NUS expanded

rm -fr test.fid

bruk2pipe -verb -in ./ser \
  -bad 0.0 -ext -aswap -AMX -decim 2320 -dspfvs 20 -grpdly 68 -ws 8 -noi2f  \
  -xN              2048  -yN             42776  -zN                 1  \
  -xT              1024  -yT               130  -zT                55  \
  -xMODE            DQD  -yMODE        Complex  -zMODE           Real  \
  -xSW         8620.690  -ySW         2000.000  -zSW         1818.182  \
  -xOBS         600.433  -yOBS          60.848  -zOBS         151.004  \
  -xCAR           4.677  -yCAR         116.741  -zCAR         175.544  \
  -xLAB              HN  -yLAB             15N  -zLAB             13C  \
  -ndim               2  -aq2D         Complex                         \
-out test.fid -ov

rm -fr fid

set idxExpmt  = ( 1 2 )

set nExp=${#idxExpmt}
set n=1
set bits=()

while ( $n <= $nExp )
   set bits = ($bits 0)
   @ n++
end

foreach n (`seq 1 $nExp`)
   set bits[$n] = 1
   echo $bits

   set outName = (`printf fid/test%03d.fid $idxExpmt[$n]`)
   echo "* output = $outName"

   rm -fr temp.fid  #critical if -ov not used below for overwriting
   nmrPipe -in test.fid | nmrPipe -fn COADD -cList $bits -axis Y \
   | nmrPipe -fn MAC -macro $NMRTXT/bruk_ranceY.M -noWr -noRd -out temp.fid -ov

   nusExpand.tcl -mode pipe -in temp.fid -out $outName -qzSize 2      \
                 -sample nuslist -sampleCount 5347 -yT 130 -zT 55

   set bits[$n] = 0
end

rm -fr temp.fid test.fid

